# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))

import sys
import os
from datetime import datetime

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
# sys.path.insert(0, os.path.abspath('.'))

from pathlib import Path

HERE = Path(__file__).parent
sys.path.insert(0, f"{HERE.parent}")

import dyntrack


# -- Project information -----------------------------------------------------

project = "dyntrack"
author = "Louis Faure"
copyright = f"{datetime.now():%Y}, {author}"


version = dyntrack.__version__  #'0.1.3' #
# The full version, including alpha/beta/rc tags.
release = version


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    "sphinx.ext.napoleon",
    "sphinx.ext.intersphinx",
    "sphinx.ext.githubpages",
    "sphinx_autodoc_typehints",
    # "edit_on_github",
]

autosummary_generate = True
autoclass_content = "both"

intersphinx_mapping = dict(
    matplotlib=("https://matplotlib.org/", None),
    numpy=("https://docs.scipy.org/doc/numpy/", None),
    pandas=("https://pandas.pydata.org/pandas-docs/stable/", None),
    simpleppt=("https://simpleppt.readthedocs.io/en/latest/", None),
)

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"
html_theme_options = {
    "titles_only": True,
    "logo_only": True,
    # Toc options
    "collapse_navigation": True,
    "sticky_navigation": True,
    "navigation_depth": 4,
    "includehidden": True,
    "titles_only": False,
}
# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

html_context = dict(
    display_github=True,  # Integrate GitHub
    github_user="LouisFaure",  # Username
    github_repo="dyntrack",  # Repo name
    github_version="main",  # Version
    conf_py_path="/docs/",  # Path in the checkout to the docs root
)

html_show_sphinx = False
html_logo = "_static/dyntrack_logo.svg"
html_static_path = ["_static"]
html_extra_path = ["_extra"]


def setup(app):
    app.add_css_file("custom.css")



from setuptools import setup
from setuptools.command.build_ext import build_ext
import subprocess

class VfkmBuildExt(build_ext):
    def run(self):
        # Run make command in vfkm directory
        subprocess.check_call(['make', '-C', 'vfkm'])
        super().run()

setup(
    cmdclass={
        'build_ext': VfkmBuildExt,
    }
)
